import { world, system, BlockPermutation, ItemStack, GameMode } from "@minecraft/server";

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  const ironEvaporator = [
    "nicothekid:iron_evaporator",
    "nicothekid:iron_evaporator_with_blue_ice",
    "nicothekid:iron_evaporator_with_cheese",
    "nicothekid:iron_evaporator_with_crying_obsidian",
    "nicothekid:iron_evaporator_with_ice",
    "nicothekid:iron_evaporator_with_lava",
    "nicothekid:iron_evaporator_with_leather_scrap_1",
    "nicothekid:iron_evaporator_with_leather_scrap_2",
    "nicothekid:iron_evaporator_with_leather_scrap_3",
    "nicothekid:iron_evaporator_with_milk",
    "nicothekid:iron_evaporator_with_mud",
    "nicothekid:iron_evaporator_with_obsidian",
    "nicothekid:iron_evaporator_with_packed_ice",
    "nicothekid:iron_evaporator_with_packed_mud",
    "nicothekid:iron_evaporator_with_rotten_flesh_1",
    "nicothekid:iron_evaporator_with_rotten_flesh_2",
    "nicothekid:iron_evaporator_with_rotten_flesh_3",
    "nicothekid:iron_evaporator_with_salt",
    "nicothekid:iron_evaporator_with_snow",
    "nicothekid:iron_evaporator_with_tearing_lava",
    "nicothekid:iron_evaporator_with_water"
  ]
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:iron_evaporator_interaction", {
    onPlayerInteract: eventData => {
      const player = eventData.player;
      const block = eventData.block;
      const blockLocation = block.location;
      const playerEquippable = player.getComponent("equippable");
      const itemUsed = playerEquippable.getEquipment("Mainhand");
      function decreaseItem () {
        system.run(() => {
          if (!player.matches({ gameMode: GameMode.creative })) {
            const decrementItem = itemUsed.amount == 1 ? undefined : (itemUsed.amount--, itemUsed);
            playerEquippable.setEquipment("Mainhand", decrementItem)
          }
        });
      }
      function giveEmptyBucket () {
        const emptyBucket = new ItemStack ("minecraft:bucket", 1);
        playerEquippable.setEquipment("Mainhand", emptyBucket)
      }
      if (player.isSneaking) return;
      if (block.hasTag("iron_evaporator") || ironEvaporator.includes(block.typeId)) {
        if (block.typeId === "nicothekid:iron_evaporator") {
          const validInputs = [
            "minecraft:blue_ice",
            "minecraft:ice",
            "minecraft:lava_bucket",
            "minecraft:milk_bucket",
            "minecraft:mud",
            "minecraft:packed_ice",
            "minecraft:rotten_flesh",
            "minecraft:snow",
            "minecraft:water_bucket",
            "nicothekid:jar_of_water_full"
          ]
          if (itemUsed === undefined || !validInputs.includes(itemUsed.typeId)) return;
          if (itemUsed.typeId === "minecraft:blue_ice") {
            decreaseItem ();
            block.dimension.playSound("dig.stone", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_blue_ice"));
          }
          if (itemUsed.typeId === "minecraft:ice") {
            decreaseItem ();
            block.dimension.playSound("dig.stone", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_ice"));
          }
          if (itemUsed.typeId === "minecraft:lava_bucket") {
            giveEmptyBucket ();
            block.dimension.playSound("bucket.empty_lava", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_lava"));
          }
          if (itemUsed.typeId === "minecraft:milk_bucket") {
            giveEmptyBucket ();
            block.dimension.playSound("bucket.empty_water", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_milk"));
          }
          if (itemUsed.typeId === "minecraft:mud") {
            decreaseItem ();
            block.dimension.playSound("dig.stone", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_mud"));
          }
          if (itemUsed.typeId === "minecraft:packed_ice") {
            decreaseItem ();
            block.dimension.playSound("dig.stone", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_packed_ice"));
          }
          if (itemUsed.typeId === "minecraft:rotten_flesh") {
            decreaseItem ();
            block.dimension.playSound("cake.add_candle", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_rotten_flesh_1"));
            return;
          }
          if (itemUsed.typeId === "minecraft:snow") {
            decreaseItem ();
            block.dimension.playSound("use.snow", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_snow"));
          }
          if (itemUsed.typeId === "minecraft:water_bucket") {
            giveEmptyBucket ();
            block.dimension.playSound("bucket.empty_water", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_water"));
          }
          if (itemUsed.typeId === "nicothekid:jar_of_water_full") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.7 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_jar 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_water"));
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_blue_ice") {
          if (itemUsed === undefined || itemUsed.typeId !== "minecraft:blue_ice") {
            const spawnBlueIce = new ItemStack ("minecraft:blue_ice", 1);
            block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnItem(spawnBlueIce, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
          else if (itemUsed.typeId === "minecraft:blue_ice") {
            block.dimension.playSound("block.click.fail", blockLocation, { pitch: 1.0, volume: 0.7 });
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_cheese") {
          const setCount = Math.random() * (4 - 3) + 3;
          const spawnCheese = new ItemStack ("nicothekid:cheese", setCount);
          block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnItem(spawnCheese, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_crying_obsidian") {
          const spawnCryingObsidian = new ItemStack ("minecraft:crying_obsidian", 1);
          block.dimension.playSound("dig.stone", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnItem(spawnCryingObsidian, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_ice") {
          if (itemUsed === undefined || itemUsed.typeId !== "minecraft:ice") {
            const spawnIce = new ItemStack ("minecraft:ice", 1);
            block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnItem(spawnIce, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
          else if (itemUsed.typeId === "minecraft:ice") {
            block.dimension.playSound("block.click.fail", blockLocation, { pitch: 1.0, volume: 0.7 });
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_lava") {
          if (itemUsed === undefined) return;
          if (itemUsed.typeId === "minecraft:bucket") {
            decreaseItem ();
            block.dimension.playSound("bucket.fill_lava", blockLocation, { pitch: 1.0, volume: 0.7 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:lava_bucket 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
          if (itemUsed.typeId === "minecraft:ghast_tear") {
            decreaseItem ();
            block.dimension.playSound("random.fizz", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_tearing_lava"));
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_leather_scrap_1") {
          const setCount = Math.random() * (4 - 3) + 3;
          const spawnLeatherScrap = new ItemStack ("nicothekid:leather_scrap", setCount);
          block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnItem(spawnLeatherScrap, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_leather_scrap_2") {
          const setCount = Math.random() * (7 - 6) + 6;
          const spawnLeatherScrap = new ItemStack ("nicothekid:leather_scrap", setCount);
          block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnItem(spawnLeatherScrap, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_leather_scrap_3") {
          const setCount = Math.random() * (10 - 9) + 9;
          const spawnLeatherScrap = new ItemStack ("nicothekid:leather_scrap", setCount);
          block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnItem(spawnLeatherScrap, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_milk") {
          if (itemUsed === undefined) return;
          if (itemUsed.typeId === "minecraft:bucket") {
            decreaseItem ();
            block.dimension.playSound("bucket.fill_water", blockLocation, { pitch: 1.0, volume: 0.7 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:milk_bucket 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_mud") {
          if (itemUsed === undefined || itemUsed.typeId !== "minecraft:mud") {
            const spawnIce = new ItemStack ("minecraft:mud", 1);
            block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnItem(spawnIce, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
          else if (itemUsed.typeId === "minecraft:mud") {
            block.dimension.playSound("block.click.fail", blockLocation, { pitch: 1.0, volume: 0.7 });
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_obsidian") {
          const spawnObsidian = new ItemStack ("minecraft:obsidian", 1);
          block.dimension.playSound("dig.stone", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnItem(spawnObsidian, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_packed_ice") {
          if (itemUsed === undefined || itemUsed.typeId !== "minecraft:packed_ice") {
            const spawnPackedIce = new ItemStack ("minecraft:packed_ice", 1);
            block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnItem(spawnPackedIce, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
          else if (itemUsed.typeId === "minecraft:packed_ice") {
            block.dimension.playSound("block.click.fail", blockLocation, { pitch: 1.0, volume: 0.7 });
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_packed_mud") {
          const spawnObsidian = new ItemStack ("minecraft:packed_mud", 1);
          block.dimension.playSound("dig.stone", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnItem(spawnObsidian, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_rotten_flesh_1") {
          if (itemUsed === undefined || itemUsed.typeId !== "minecraft:rotten_flesh") {
            const spawnRottenFlesh = new ItemStack ("minecraft:rotten_flesh", 1);
            block.dimension.playSound("cake.add_candle", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnItem(spawnRottenFlesh, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
          else if (itemUsed.typeId === "minecraft:rotten_flesh") {
            decreaseItem ();
            block.dimension.playSound("cake.add_candle", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_rotten_flesh_2"));
            return;
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_rotten_flesh_2") {
          if (itemUsed === undefined || itemUsed.typeId !== "minecraft:rotten_flesh") {
            const spawnRottenFlesh = new ItemStack ("minecraft:rotten_flesh", 2);
            block.dimension.playSound("cake.add_candle", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnItem(spawnRottenFlesh, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
          else if (itemUsed.typeId === "minecraft:rotten_flesh") {
            decreaseItem ();
            block.dimension.playSound("cake.add_candle", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_rotten_flesh_3"));
            return;
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_rotten_flesh_3") {
          if (itemUsed === undefined || itemUsed.typeId !== "minecraft:rotten_flesh") {
            const spawnRottenFlesh = new ItemStack ("minecraft:rotten_flesh", 3);
            block.dimension.playSound("cake.add_candle", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnItem(spawnRottenFlesh, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
          else if (itemUsed.typeId === "minecraft:rotten_flesh") {
            block.dimension.playSound("block.click.fail", blockLocation, { pitch: 1.0, volume: 0.7 });
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_salt") {
          const setCount = Math.random() * (4 - 3) + 3;
          const spawnSalt = new ItemStack ("nicothekid:salt", setCount);
          block.dimension.playSound("dig.sand", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnItem(spawnSalt, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_snow") {
          if (itemUsed === undefined || itemUsed.typeId !== "minecraft:snow") {
            const spawnSnow = new ItemStack ("minecraft:snow", 1);
            block.dimension.playSound("dig.snow", blockLocation, { pitch: 1.0, volume: 0.7 });
            block.dimension.spawnItem(spawnSnow, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
          else if (itemUsed.typeId === "minecraft:snow") {
            block.dimension.playSound("block.click.fail", blockLocation, { pitch: 1.0, volume: 0.7 });
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_tearing_lava") {
          if (itemUsed === undefined) return;
          if (itemUsed.typeId === "minecraft:bucket") {
            decreaseItem ();
            block.dimension.playSound("bucket.fill_lava", blockLocation, { pitch: 1.0, volume: 0.7 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:lava_bucket 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
          }
        }
        if (block.typeId === "nicothekid:iron_evaporator_with_water") {
          if (itemUsed === undefined) return;
          if (itemUsed.typeId === "minecraft:bucket") {
            decreaseItem ();
            block.dimension.playSound("bucket.fill_water", blockLocation, { pitch: 1.0, volume: 0.7 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:water_bucket 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
            return;
          }
          if (itemUsed.typeId === "nicothekid:empty_jar") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.7 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:jar_of_water_full 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator"));
            return;
          }
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.7 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_water 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            return;
          }
        }
      }
    }
  });
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:iron_evaporator_ticks", {
    onTick: eventData => {
      const block = eventData.block;
      const blockLocation = block.location;
      if (ironEvaporator.includes(block.typeId)) {
        if (block.permutation.matches("nicothekid:iron_evaporator_with_blue_ice")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 0.5 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_packed_ice"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_ice")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_water"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_lava")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_obsidian"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_milk")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_cheese"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_mud")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 0.7 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_packed_mud"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_packed_ice")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 0.5 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_ice"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_rotten_flesh_1")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_leather_scrap_1"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_rotten_flesh_2")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_leather_scrap_2"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_rotten_flesh_3")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_leather_scrap_3"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_snow")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_water"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_tearing_lava")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_crying_obsidian"));
          return
        }
        if (block.permutation.matches("nicothekid:iron_evaporator_with_water")) {
          block.dimension.playSound("step.powder_snow", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.spawnParticle("nicothekid:evaporator_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:iron_evaporator_with_salt"));
          return
        }
      }
    }
  });
});
