import { world, system, BlockPermutation, ItemStack, GameMode } from "@minecraft/server";

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:jar_of_cookies_interaction", {
    onPlayerInteract: eventData => {
      const player = eventData.player;
      const block = eventData.block;
      const blockLocation = block.location;
      const playerEquippable = player.getComponent("equippable");
      const itemUsed = playerEquippable.getEquipment("Mainhand");
      const blockState = block.permutation.getState("minecraft:cardinal_direction");
      const blockAllState = block.permutation.getAllStates();
      function damageDurability () {
        if (!player.matches({ gameMode: GameMode.creative })) {
          const itemEnchantable = itemUsed.getComponent("enchantable");
          const unbreakingLevel = itemEnchantable?.getEnchantment("unbreaking")?.level ?? 0;
          const breakChance = 100 / (unbreakingLevel + 1);
          const randomizeChance = Math.random() * 100;
          if (breakChance < randomizeChance) return;
          const itemDurability = itemUsed.getComponent("durability");
          if (!itemDurability) return;
          const itemMaxDurability = itemDurability.maxDurability;
          const itemDurabilityDamage = itemDurability.damage;
          const durabilityCalculation = itemMaxDurability - itemDurabilityDamage;
          let damageAmount = 1;
          const currentDurability = durabilityCalculation - damageAmount;
          if (currentDurability <= 0) {
            player.playSound("random.break", { pitch: 0.9, location: player.location, volume: 1 });
            playerEquippable.setEquipment("Mainhand", null);
          }
          else {
            itemDurability.damage += damageAmount;
            playerEquippable.setEquipment("Mainhand", itemUsed)
          }
        }
      }
      function decreaseItem () {
        system.run(() => {
          if (!player.matches({ gameMode: GameMode.creative })) {
            const decrementItem = itemUsed.amount == 1 ? undefined : (itemUsed.amount--, itemUsed);
            playerEquippable.setEquipment("Mainhand", decrementItem)
          }
        });
      }
      const cookieJars = [
        "nicothekid:empty_jar",
        "nicothekid:jar_of_cookies_1",
        "nicothekid:jar_of_cookies_2",
        "nicothekid:jar_of_cookies_3",
        "nicothekid:jar_of_cookies_4",
        "nicothekid:jar_of_cookies_5",
        "nicothekid:jar_of_cookies_6",
        "nicothekid:jar_of_cookies_7",
        "nicothekid:jar_of_cookies_8",
        "nicothekid:jar_of_glow_berry_cookies_1",
        "nicothekid:jar_of_glow_berry_cookies_2",
        "nicothekid:jar_of_glow_berry_cookies_3",
        "nicothekid:jar_of_glow_berry_cookies_4",
        "nicothekid:jar_of_glow_berry_cookies_5",
        "nicothekid:jar_of_glow_berry_cookies_6",
        "nicothekid:jar_of_glow_berry_cookies_7",
        "nicothekid:jar_of_glow_berry_cookies_8",
        "nicothekid:jar_of_sweet_berry_cookies_1",
        "nicothekid:jar_of_sweet_berry_cookies_2",
        "nicothekid:jar_of_sweet_berry_cookies_3",
        "nicothekid:jar_of_sweet_berry_cookies_4",
        "nicothekid:jar_of_sweet_berry_cookies_5",
        "nicothekid:jar_of_sweet_berry_cookies_6",
        "nicothekid:jar_of_sweet_berry_cookies_7",
        "nicothekid:jar_of_sweet_berry_cookies_8"
      ]
      if (player.isSneaking) return;
      if (cookieJars.includes(block.typeId)) {
        if (itemUsed === undefined) {
          const fullCookieJars = [
            "nicothekid:jar_of_cookies_8",
            "nicothekid:jar_of_glow_berry_cookies_8",
            "nicothekid:jar_of_sweet_berry_cookies_8"
          ]
          if (fullCookieJars.includes(block.typeId)) {
            player.playSound("game.player.attack.nodamage", { pitch: 1.1, location: blockLocation, volume: 1.0 });
            player.runCommandAsync(`tellraw @p {\"rawtext\":[{\"text\":\"§eUse the Jar Opener to take out one of the cookies.§r\"}]}`);
          }
          else return;
        }
        else if (itemUsed !== undefined) {
          const validCookies = [
            "minecraft:cookie",
            "nicothekid:glow_berry_cookie",
            "nicothekid:sweet_berry_cookie"
          ]
          if (itemUsed.typeId === "nicothekid:jar_opener") {
            if (block.hasTag("jar_of_cookies")) {
              damageDurability ();
              block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.5 });
              const spawnCookie = new ItemStack ("minecraft:cookie", 1);
              block.dimension.spawnItem(spawnCookie, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
              if (block.permutation.matches("nicothekid:jar_of_cookies_1")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_2")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_1", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_3")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_2", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_4")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_3", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_5")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_4", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_6")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_5", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_7")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_6", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_8")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_7", blockAllState ));
                return;
              }
            }
            if (block.hasTag("jar_of_glow_berry_cookies")) {
              damageDurability ();
              block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.5 });
              const spawnGlowBerryCookie = new ItemStack ("nicothekid:glow_berry_cookie", 1);
              block.dimension.spawnItem(spawnGlowBerryCookie, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_1")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_2")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_1", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_3")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_2", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_4")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_3", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_5")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_4", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_6")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_5", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_7")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_6", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_8")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_7", blockAllState ));
                return;
              }
            }
            if (block.hasTag("jar_of_sweet_berry_cookies")) {
              damageDurability ();
              block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 1.0, volume: 0.5 });
              const spawnSweetBerryCookie = new ItemStack ("nicothekid:sweet_berry_cookie", 1);
              block.dimension.spawnItem(spawnSweetBerryCookie, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_1")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_2")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_1", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_3")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_2", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_4")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_3", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_5")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_4", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_6")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_5", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_7")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_6", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_8")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_7", blockAllState ));
                return;
              }
            }
          }
          else if (validCookies.includes(itemUsed.typeId)) {
            if (itemUsed.typeId === "minecraft:cookie") {
              const inputableJars = [
                "nicothekid:empty_jar",
                "nicothekid:jar_of_cookies_1",
                "nicothekid:jar_of_cookies_2",
                "nicothekid:jar_of_cookies_3",
                "nicothekid:jar_of_cookies_4",
                "nicothekid:jar_of_cookies_5",
                "nicothekid:jar_of_cookies_6",
                "nicothekid:jar_of_cookies_7"
              ];
              if (!inputableJars.includes(block.typeId)) return;
              decreaseItem ();
              block.dimension.playSound("block.itemframe.add_item", blockLocation, { pitch: 1.0, volume: 0.5 });
              if (block.permutation.matches("nicothekid:empty_jar")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_1", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_1")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_2", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_2")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_3", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_3")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_4", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_4")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_5", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_5")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_6", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_6")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_7", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_cookies_7")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_cookies_8", blockAllState ));
                return;
              }
            }
            if (itemUsed.typeId === "nicothekid:glow_berry_cookie") {
              const inputableJars = [
                "nicothekid:empty_jar",
                "nicothekid:jar_of_glow_berry_cookies_1",
                "nicothekid:jar_of_glow_berry_cookies_2",
                "nicothekid:jar_of_glow_berry_cookies_3",
                "nicothekid:jar_of_glow_berry_cookies_4",
                "nicothekid:jar_of_glow_berry_cookies_5",
                "nicothekid:jar_of_glow_berry_cookies_6",
                "nicothekid:jar_of_glow_berry_cookies_7"
              ];
              if (!inputableJars.includes(block.typeId)) return;
              decreaseItem ();
              block.dimension.playSound("block.itemframe.add_item", blockLocation, { pitch: 1.0, volume: 0.5 });
              if (block.permutation.matches("nicothekid:empty_jar")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_1", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_1")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_2", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_2")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_3", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_3")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_4", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_4")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_5", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_5")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_6", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_6")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_7", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_glow_berry_cookies_7")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_cookies_8", blockAllState ));
                return;
              }
            }
            if (itemUsed.typeId === "nicothekid:sweet_berry_cookie") {
              const inputableJars = [
                "nicothekid:empty_jar",
                "nicothekid:jar_of_sweet_berry_cookies_1",
                "nicothekid:jar_of_sweet_berry_cookies_2",
                "nicothekid:jar_of_sweet_berry_cookies_3",
                "nicothekid:jar_of_sweet_berry_cookies_4",
                "nicothekid:jar_of_sweet_berry_cookies_5",
                "nicothekid:jar_of_sweet_berry_cookies_6",
                "nicothekid:jar_of_sweet_berry_cookies_7"
              ];
              if (!inputableJars.includes(block.typeId)) return;
              decreaseItem ();
              block.dimension.playSound("block.itemframe.add_item", blockLocation, { pitch: 1.0, volume: 0.5 });
              if (block.permutation.matches("nicothekid:empty_jar")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_1", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_1")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_2", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_2")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_3", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_3")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_4", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_4")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_5", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_5")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_6", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_6")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_7", blockAllState ));
                return;
              }
              if (block.permutation.matches("nicothekid:jar_of_sweet_berry_cookies_7")) {
                block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_cookies_8", blockAllState ));
                return;
              }
            }
          }
          else return;
        }
      }
      else return;
    }
  });
});
