import { world, system, BlockPermutation, ItemStack, GameMode } from "@minecraft/server";

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:jar_of_drinks_interaction", {
    onPlayerInteract: eventData => {
      const player = eventData.player;
      const block = eventData.block;
      const blockFacing = eventData.face;
      const blockLocation = block.location;
      const playerEquippable = player.getComponent("equippable");
      const itemUsed = playerEquippable.getEquipment("Mainhand");
      const blockAllState = block.permutation.getAllStates();
      function damageDurability () {
        if (!player.matches({ gameMode: GameMode.creative })) {
          const itemEnchantable = itemUsed.getComponent("enchantable");
          const unbreakingLevel = itemEnchantable?.getEnchantment("unbreaking")?.level ?? 0;
          const breakChance = 100 / (unbreakingLevel + 1);
          const randomizeChance = Math.random() * 100;
          if (breakChance < randomizeChance) return;
          const itemDurability = itemUsed.getComponent("durability");
          if (!itemDurability) return;
          const itemMaxDurability = itemDurability.maxDurability;
          const itemDurabilityDamage = itemDurability.damage;
          const durabilityCalculation = itemMaxDurability - itemDurabilityDamage;
          let damageAmount = 1;
          const currentDurability = durabilityCalculation - damageAmount;
          if (currentDurability <= 0) {
            player.playSound("random.break", { pitch: 0.9, location: player.location, volume: 1 });
            playerEquippable.setEquipment("Mainhand", null);
          }
          else {
            itemDurability.damage += damageAmount;
            playerEquippable.setEquipment("Mainhand", itemUsed)
          }
        }
      }
      function decreaseItem () {
        system.run(() => {
          if (!player.matches({ gameMode: GameMode.creative })) {
            const decrementItem = itemUsed.amount == 1 ? undefined : (itemUsed.amount--, itemUsed);
            playerEquippable.setEquipment("Mainhand", decrementItem)
          }
        });
      }
      const drinkJars = [
        "nicothekid:empty_jar",
        "nicothekid:jar_of_chocolate_full",
        "nicothekid:jar_of_chocolate_half",
        "nicothekid:jar_of_glow_berry_juice_full",
        "nicothekid:jar_of_glow_berry_juice_half",
        "nicothekid:jar_of_honey_full",
        "nicothekid:jar_of_honey_half",
        "nicothekid:jar_of_milk_full",
        "nicothekid:jar_of_milk_half",
        "nicothekid:jar_of_sweet_berry_juice_full",
        "nicothekid:jar_of_sweet_berry_juice_half",
        "nicothekid:jar_of_water_full",
        "nicothekid:jar_of_water_half"
      ];
      const validLiquids = [
        "minecraft:bucket",
        "minecraft:milk_bucket",
        "minecraft:glass_bottle",
        "minecraft:honey_bottle",
        "minecraft:potion",
        "nicothekid:empty_bamboo_tumbler",
        "nicothekid:bamboo_tumbler_with_chocolate",
        "nicothekid:bamboo_tumbler_with_glow_berry_juice",
        "nicothekid:bamboo_tumbler_with_milk",
        "nicothekid:bamboo_tumbler_with_sweet_berry_juice",
        "nicothekid:bamboo_tumbler_with_water"
      ];
      if (player.isSneaking || itemUsed === undefined || blockFacing === "Up") return;
      if (drinkJars.includes(block.typeId) && validLiquids.includes(itemUsed.typeId)) {
        if (block.permutation.matches("nicothekid:empty_jar")) {
          if (itemUsed.typeId === "minecraft:milk_bucket") {
            decreaseItem ();
            block.dimension.playSound("bucket.empty_water", blockLocation, { pitch: 1.0, volume: 0.7 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:bucket 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_milk_full", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "minecraft:honey_bottle") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:glass_bottle 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_honey_half", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "minecraft:potion") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:glass_bottle 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_water_half", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_chocolate") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_chocolate_half", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_glow_berry_juice") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });        
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_juice_half", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_milk") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_milk_half", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_sweet_berry_juice") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_juice_half", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_water") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_water_half", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_chocolate_half")) {
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_chocolate 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_chocolate") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_chocolate_full", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_chocolate_full")) {
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_chocolate 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_chocolate_half", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_glow_berry_juice_half")) {
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_glow_berry_juice 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_glow_berry_juice") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_juice_full", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_glow_berry_juice_full")) {
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_glow_berry_juice 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_glow_berry_juice_half", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_honey_half")) {
          if (itemUsed.typeId === "minecraft:glass_bottle") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:honey_bottle 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "minecraft:honey_bottle") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:glass_bottle 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_honey_full", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_honey_full")) {
          if (itemUsed.typeId === "minecraft:glass_bottle") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:honey_bottle 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_honey_half", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_milk_half")) {
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_milk 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_milk") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_milk_full", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_milk_full")) {
          if (itemUsed.typeId === "minecraft:bucket") {
            decreaseItem ();
            block.dimension.playSound("bucket.fill_water", blockLocation, { pitch: 1.0, volume: 0.7 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:milk_bucket 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_milk 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_milk_half", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_sweet_berry_juice_half")) {
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_sweet_berry_juice 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_sweet_berry_juice") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_juice_full", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_sweet_berry_juice_full")) {
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_sweet_berry_juice 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_sweet_berry_juice_half", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_water_half")) {
          if (itemUsed.typeId === "minecraft:glass_bottle") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:potion 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "minecraft:potion") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:glass_bottle 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_water_full", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_water 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:empty_jar", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:bamboo_tumbler_with_water") {
            decreaseItem ();
            block.dimension.playSound("bottle.empty", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:empty_bamboo_tumbler 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_water_full", blockAllState ));
            return;
          }
        }
        if (block.permutation.matches("nicothekid:jar_of_water_full")) {
          if (itemUsed.typeId === "minecraft:glass_bottle") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s minecraft:potion 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_water_half", blockAllState ));
            return;
          }
          if (itemUsed.typeId === "nicothekid:empty_bamboo_tumbler") {
            decreaseItem ();
            block.dimension.playSound("bottle.fill", blockLocation, { pitch: 1.0, volume: 0.5 });
            player.runCommandAsync(`gamerule sendcommandfeedback false`);
            player.runCommandAsync(`give @s nicothekid:bamboo_tumbler_with_water 1`);
            player.runCommandAsync(`gamerule sendcommandfeedback true`);
            block.setPermutation(BlockPermutation.resolve("nicothekid:jar_of_water_half", blockAllState ));
            return;
          }
        }
      }
      else return;
    }
  });
});
