import { world, system, BlockPermutation, ItemStack, GameMode } from "@minecraft/server";

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:sparrow_egg_block_on_player_interact", {
    onPlayerInteract: eventData => {
      const player = eventData.player;
      const block = eventData.block;
      const blockLocation = block.location;
      const playerEquippable = player.getComponent("equippable");
      const itemUsed = playerEquippable.getEquipment("Mainhand");
      const blockState = block.permutation.getState("minecraft:cardinal_direction");
      const blockAllState = block.permutation.getAllStates();
      function decreaseItem () {
        system.run(() => {
          if (!player.matches({ gameMode: GameMode.creative })) {
            const decrementItem = itemUsed.amount == 1 ? undefined : (itemUsed.amount--, itemUsed);
            playerEquippable.setEquipment("Mainhand", decrementItem)
          }
        });
      }
      function spawnSparrowEgg () {
        system.run(() => {
          const itemSparrowEgg = new ItemStack ("nicothekid:sparrow_egg", 1);
          block.dimension.spawnItem(itemSparrowEgg, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
        });
      }
      if (itemUsed === undefined && !player.isSneaking || itemUsed.typeId !== "nicothekid:sparrow_egg" && !player.isSneaking) {
        if (block.typeId === "nicothekid:sparrow_egg_1_block") {
          spawnSparrowEgg ();
          block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 0.8, volume: 1.0 });
          block.setPermutation(BlockPermutation.resolve("minecraft:air"));
          return;
        }
        if (block.typeId === "nicothekid:sparrow_egg_2_block") {
          spawnSparrowEgg ();
          block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 0.8, volume: 1.0 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:sparrow_egg_1_block", blockAllState ));
          return;
        }
        if (block.typeId === "nicothekid:sparrow_egg_3_block") {
          spawnSparrowEgg ();
          block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 0.8, volume: 1.0 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:sparrow_egg_2_block", blockAllState));
          return;
        }
        if (block.typeId === "nicothekid:sparrow_egg_4_block") {
          spawnSparrowEgg ();
          block.dimension.playSound("block.itemframe.remove_item", blockLocation, { pitch: 0.8, volume: 1.0 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:sparrow_egg_3_block", blockAllState));
          return;
        }
      }
      else if (itemUsed.typeId === "nicothekid:sparrow_egg") {
        if (block.typeId === "nicothekid:sparrow_egg_1_block") {
          decreaseItem ();
          block.dimension.playSound("block.itemframe.add_item", blockLocation, { pitch: 1.0, volume: 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:sparrow_egg_2_block", blockAllState));
          return;
        }
        if (block.typeId === "nicothekid:sparrow_egg_2_block") {
          decreaseItem ();
          block.dimension.playSound("block.itemframe.add_item", blockLocation, { pitch: 1.0, volume: 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:sparrow_egg_3_block", blockAllState));
          return;
        }
        if (block.typeId === "nicothekid:sparrow_egg_3_block") {
          decreaseItem ();
          block.dimension.playSound("block.itemframe.add_item", blockLocation, { pitch: 1.0, volume: 0.5 });
          block.setPermutation(BlockPermutation.resolve("nicothekid:sparrow_egg_4_block", blockAllState));
          return;
        }
      }
      else return;
    }
  });
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:sparrow_egg_block_on_tick", {
    onTick: eventData => {
      const block = eventData.block;
      const blockLocation = block.location;
      if (block.permutation.matches("nicothekid:sparrow_egg_1_block")) {
        system.run(() => {
          block.setPermutation(BlockPermutation.resolve("minecraft:air"));
          block.dimension.playSound("block.turtle_egg.crack", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          return;
        });
      }
      if (block.permutation.matches("nicothekid:sparrow_egg_2_block")) {
        system.run(() => {
          block.setPermutation(BlockPermutation.resolve("minecraft:air"));
          block.dimension.playSound("block.turtle_egg.crack", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          return;
        });
      }
      if (block.permutation.matches("nicothekid:sparrow_egg_3_block")) {
        system.run(() => {
          block.setPermutation(BlockPermutation.resolve("minecraft:air"));
          block.dimension.playSound("block.turtle_egg.crack", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          return;
        });
      }
      if (block.permutation.matches("nicothekid:sparrow_egg_4_block")) {
        system.run(() => {
          block.setPermutation(BlockPermutation.resolve("minecraft:air"));
          block.dimension.playSound("block.turtle_egg.crack", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          block.dimension.runCommandAsync(`summon nicothekid:sparrow ${blockLocation.x + 0.5} ${blockLocation.y} ${blockLocation.z + 0.5} ~ ~ event:spawn_from_egg`);
          return;
        });
      }
    }
  });
});