import { world, system, BlockPermutation, ItemStack, GameMode } from "@minecraft/server";

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  const sporePots = [
    "nicothekid:spore_pot",
    "nicothekid:amethyst_spore_pot",
    "nicothekid:blaze_spore_pot",
    "nicothekid:charcoal_spore_pot",
    "nicothekid:cocoa_spore_pot",
    "nicothekid:diamond_spore_pot",
    "nicothekid:emerald_spore_pot",
    "nicothekid:enchanted_spore_pot",
    "nicothekid:glowstone_spore_pot",
    "nicothekid:gold_spore_pot",
    "nicothekid:gunpowder_spore_pot",
    "nicothekid:iron_spore_pot",
    "nicothekid:lapis_lazuli_spore_pot",
    "nicothekid:netherite_spore_pot",
    "nicothekid:redstone_spore_pot",
    "nicothekid:sugar_spore_pot"
  ]
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:spore_pot_interaction", {
    onPlayerInteract: eventData => {
      const player = eventData.player;
      const block = eventData.block;
      const blockLocation = block.location;
      const playerLocation = block.location; // It's same location of block for now, currently bugged when item spawn at player location it doesn't add immediately in player's inventory.
      const playerEquippable = player.getComponent("equippable");
      const itemUsed = playerEquippable.getEquipment("Mainhand");
      function decreaseItem () {
        system.run(() => {
          if (!player.matches({ gameMode: GameMode.creative })) {
            const decrementItem = itemUsed.amount == 1 ? undefined : (itemUsed.amount--, itemUsed);
            playerEquippable.setEquipment("Mainhand", decrementItem)
          }
        });
      }
      if (player.isSneaking) return;
      if (sporePots.includes(block.typeId)) {
        if (block.typeId === "nicothekid:spore_pot") {
          const validInputs = [
            "minecraft:blaze_powder",
            "minecraft:glowstone_dust",
            "minecraft:gunpowder",
            "minecraft:redstone",
            "minecraft:sugar",
            "nicothekid:amethyst_powder",
            "nicothekid:charcoal_powder",
            "nicothekid:cocoa_powder",
            "nicothekid:diamond_powder",
            "nicothekid:emerald_powder",
            "nicothekid:enchanted_dust",
            "nicothekid:gold_powder",
            "nicothekid:iron_powder",
            "nicothekid:lapis_lazuli_powder",
            "nicothekid:netherite_powder"
          ]
          if (itemUsed === undefined) {
            player.playSound("game.player.attack.nodamage", { pitch: 1.1, location: player.location, volume: 1.0 });
            player.runCommandAsync(`tellraw @p {\"rawtext\":[{\"text\":\"§eUse any type of powder or dust to active the Spore Pot.§r\"}]}`);
            return;
          }
          else if (validInputs.includes(itemUsed.typeId)) {
            decreaseItem ();
            block.dimension.playSound("item.bone_meal.use", blockLocation, { pitch: 1.0, volume: 0.8 });
            if (itemUsed.typeId === "minecraft:blaze_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:blaze_spore_pot"));
            }
            if (itemUsed.typeId === "minecraft:glowstone_dust") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:glowstone_spore_pot"));
            }
            if (itemUsed.typeId === "minecraft:gunpowder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:gunpowder_spore_pot"));
            }
            if (itemUsed.typeId === "minecraft:redstone") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:redstone_spore_pot"));
            }
            if (itemUsed.typeId === "minecraft:sugar") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:sugar_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:amethyst_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:amethyst_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:charcoal_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:charcoal_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:cocoa_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:cocoa_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:diamond_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:diamond_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:emerald_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:emerald_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:enchanted_dust") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:enchanted_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:gold_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:gold_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:iron_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:iron_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:lapis_lazuli_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:lapis_lazuli_spore_pot"));
            }
            if (itemUsed.typeId === "nicothekid:netherite_powder") {
              block.setPermutation(BlockPermutation.resolve("nicothekid:netherite_spore_pot"));
            }
          }
          else return;
        }
        else {
          if (itemUsed === undefined) return;
          if (itemUsed.typeId === "nicothekid:salt") {
            decreaseItem ();
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 0.8 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"));
          }
          else return;
        }
      }
      else return;
    }
  });
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:spore_pot_ticks", {
    onTick: eventData => {
      const block = eventData.block;
      const blockLocation = block.location;
      if (sporePots.includes(block.typeId)) {
        if (block.permutation.matches("nicothekid:amethyst_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:amethyst_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:blaze_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:blaze_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:charcoal_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:charcoal_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:cocoa_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:cocoa_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:diamond_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:diamond_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:emerald_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:emerald_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:enchanted_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:enchanted_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:glowstone_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:glowstone_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:gold_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:gold_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:gunpowder_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:gunpowder_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:iron_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:iron_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:lapis_lazuli_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:lapis_lazuli_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:netherite_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:netherite_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:redstone_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:redstone_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
        if (block.permutation.matches("nicothekid:sugar_spore_pot")) {
          block.dimension.spawnParticle("nicothekid:sugar_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
        }
      }
      else return;
    }
  });
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:spore_pot_random_ticks", {
    onRandomTick: eventData => {
      const block = eventData.block;
      const blockLocation = block.location;
      if (sporePots.includes(block.typeId)) {
        if (block.permutation.matches("nicothekid:amethyst_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("nicothekid:amethyst_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:amethyst_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:blaze_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("minecraft:blaze_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:blaze_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:charcoal_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("nicothekid:charcoal_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:charcoal_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:cocoa_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("nicothekid:cocoa_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:cocoa_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:diamond_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("nicothekid:diamond_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:diamond_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:emerald_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("nicothekid:emerald_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:emerald_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:enchanted_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.05) {
            const spawnPowder = new ItemStack ("nicothekid:enchanted_dust", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else if (randomChance <= 0.2) {
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            block.dimension.spawnEntity("minecraft:xp_orb", { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:enchanted_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:glowstone_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("minecraft:glowstone_dust", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:glowstone_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:gold_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("nicothekid:gold_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:gold_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:gunpowder_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("minecraft:gunpowder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:gunpowder_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:iron_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("nicothekid:iron_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:iron_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:lapis_lazuli_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("nicothekid:lapis_lazuli_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:lapis_lazuli_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:netherite_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("nicothekid:netherite_powder", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:netherite_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:redstone_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("minecraft:redstone", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:redstone_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
        if (block.permutation.matches("nicothekid:sugar_spore_pot")) {
          let randomChance = Math.random();
          if (randomChance <= 0.01) {
            block.dimension.playSound("block.composter.fill", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:spore_pot"))
          }
          else if (randomChance <= 0.15) {
            const spawnPowder = new ItemStack ("minecraft:sugar", 1);
            block.dimension.playSound("block.composter.ready", blockLocation, { pitch: 1.0, volume: 1.0 });
            block.dimension.spawnItem(spawnPowder, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
          }
          else {
            block.dimension.spawnParticle("nicothekid:sugar_spore_pot_particle", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
            return;
          }
        }
      }
      else return;
    }
  });
});